# Contact us

If you encounter a bug, please [open an issue](https://github.com/MREYE-LUMC/ZOSPy/issues) on GitHub.
If you have a feature request or a different question, please [start a discussion](https://github.com/MREYE-LUMC/ZOSPy/discussions).
You can also contact us via e-mail at [zospy@mreye.nl](mailto:zospy@mreye.nl) or visit [mreye.nl](https://mreye.nl) 
to discover our research.